@@ -1,4 +1,4 @@
-from django.utils.safestring import mark_safe
+from django.utils.html import format_html
 from edc_action_item.action_with_notification import ActionWithNotification
 from edc_constants.constants import CLOSED, HIGH_PRIORITY
 
@@ -21,7 +21,7 @@ class DeathReportTmgSecondAction(ActionWithNotification):
     color_style = "info"
     show_link_to_changelist = True
     singleton = True
-    instructions = mark_safe("This report is to be completed by the TMG only.")
+    instructions = format_html("This report is to be completed by the TMG only.")
 
     reference_model = f"{ADVERSE_EVENT_APP_LABEL}.deathreporttmgsecond"
     related_reference_model = f"{ADVERSE_EVENT_APP_LABEL}.deathreport"
